@@ -11,8 +11,3 @@ pref("middlemouse.contentLoadURL", false); // setting to false disables pasting
 
 // kerberos-for-https
 pref("network.negotiate-auth.trusted-uris", "https://");
-
-// Yahoo by default
-pref("browser.search.defaultenginename", "chrome://ubufox/locale/ubufox-search.properties");
-pref("browser.search.order.1", "chrome://ubufox/locale/ubufox-search.properties");
-pref("browser.search.order.2", "chrome://ubufox/locale/ubufox-search.properties");
